@@ -18,11 +18,13 @@ import pytest
 from sn2.device import (
     ConnectionStatus,
     Device,
+    InformationData,
     InformationUpdate,
     OnOffSetting,
     SettingsUpdate,
     StateChange,
 )
+from sn2.json_model import DeviceInformation
 
 if TYPE_CHECKING:
     from collections.abc import Generator
@@ -46,7 +48,14 @@ class TestDevice:
     def device(self) -> Device:
         """Fixture to create a Device instance."""
         self.on_update_mock = AsyncMock()
-        return Device(host="192.168.1.100", on_update=self.on_update_mock)
+        return Device(
+            host="192.168.1.100",
+            initial_settings=[],
+            initial_info_data=InformationData.convert_device_information_to_data(
+                DeviceInformation(lcu="testdeviceid", hwm="1.0.0", n="test device")
+            ),
+            on_update=self.on_update_mock,
+        )
 
     @pytest.fixture
     def mock_websocket(self) -> "Generator":
